#define MSG_TIMEOUT "as vyprel"
#define MSG_CAPABILITIES "Nemohu zmnit privilegia"
#define MSG_CLIENT_CLOSED_CNX "Klient uzavel spojen"
#define MSG_CLIENT_READ_ERR "Chyba pi ten od klienta"
#define MSG_CANT_OPEN_CNX "Nemu vytvoit spojen"
#define MSG_CANT_CREATE_DATA_SOCKET "Nemu vytvoit datov socket"
#define MSG_DEBUG_CLIENT_IS "Klientova adresa je"
#define MSG_SYNTAX_ERROR_IP "Syntaktick chyba v IP adrese"
#define MSG_PORT_SUCCESSFUL "Pkaz PORT spne vykonn"
#define MSG_ONLY_IPV4V6 "Jsou podporovny pouze IPv4 a IPv6 (1,2)"
#define MSG_ONLY_IPV4 "Podporovn je pouze IPv4 (1)"
#define MSG_TIMEOUT_PARSER "as vyprel, pt zkuste pst rychleji"
#define MSG_LINE_TOO_LONG "dek je pli dlouh"
#define MSG_LOG_OVERFLOW "Klient se pokusil peplnit buffer pro pkazov dek"
#define MSG_GOODBYE "Nashledanou. Uploadli jste %llu a downloadli %llu kilobajt."
#define MSG_DEBUG_COMMAND "Pkaz"
#define MSG_IS_YOUR_CURRENT_LOCATION "je vae souasn location"
#define MSG_NOT_LOGGED_IN "Nejste pihlen"
#define MSG_AUTH_UNIMPLEMENTED "Bezpenostn rozen nejsou implementovny"
#define MSG_NO_FILE_NAME "dn jmno souboru"
#define MSG_NO_DIRECTORY_NAME "dn jmno adrese"
#define MSG_NO_RESTART_POINT "dn zatek restartu"
#define MSG_ABOR_SUCCESS "Vidte-li tohle, pak pkaz ABOR byl uspn"
#define MSG_MISSING_ARG "Chybjc argument"
#define MSG_GARBAGE_FOUND "Za hodnotou se nachz smet"
#define MSG_VALUE_TOO_LARGE "Pli vysok hodnota"
#define MSG_IDLE_TIME "as neinnosti nastaven na %lu sekund"
#define MSG_SITE_HELP "Nasledujc SITE pkazy jsou rozeznny"
#define MSG_BAD_CHMOD "Chybn pstupov prva"
#define MSG_UNKNOWN_EXTENSION "je neznm rozen"
#define MSG_XDBG_OK "Pkaz XDBG byl spn, debug rove nastavena na %d"
#define MSG_UNKNOWN_COMMAND "Neznm pkaz"
#define MSG_TIMEOUT_NOOP "as vyprel (dna operace v prbhu %lu sekund)"
#define MSG_TIMEOUT_DATA "as vyprel (dn nov data v prbhu %lu sekund)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "U jste pihlenej"
#define MSG_ANY_PASSWORD "Mete zatat libovoln heslo"
#define MSG_ANONYMOUS_LOGGED "Pihlen jako anonymn uivatel"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Anonymn uivatel se pihlsil ve virtulnm FTP"
#define MSG_USER_OK "Uivatel %s je OK. Heslo je povinn"
#define MSG_CANT_DO_TWICE "Bhem tohoto sezen to nemohu provst"
#define MSG_UNABLE_SECURE_ANON "Nemohu nastavit bezpen anonymn FTP"
#define MSG_BANDWIDTH_RESTRICTED "Vae penosov rychlost je omezena"
#define MSG_NO_PASSWORD_NEEDED MSG_ANY_PASSWORD
#define MSG_NOTRUST "Lituji, ale nemohu Vm dvovat"
#define MSG_WHOAREYOU "Prosm eknte mi, kdo jste"
#define MSG_AUTH_FAILED "Lituji, ale autentifikace zlyhala"
#define MSG_AUTH_TOOMANY "Pli mnoho zlyhan autentifikace"
#define MSG_NO_HOMEDIR "Domovsk adres je nepstupn - konec"
#define MSG_NO_HOMEDIR2 "%s neexistuje nebo nen dosaiteln"
#define MSG_START_SLASH "Zanm v /"
#define MSG_USER_GROUP_ACCESS "Uivatel %s m skupinov pstup do"
#define MSG_FXP_SUPPORT "Tento server podporuje FXP penosy"
#define MSG_RATIO "Muste dodrovat pomr %u:%u (UL/DL)"
#define MSG_CHROOT_FAILED "Nemohu vytvoit bezpenou chroot() klec"
#define MSG_CURRENT_DIR_IS "OK. Aktualn adres je %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Aktualn omezen adres je %s"
#define MSG_IS_NOW_LOGGED_IN "%s je prav pihlen"
#define MSG_CANT_CHANGE_DIR "Nemu pejt do adrese %s"
#define MSG_PATH_TOO_LONG "Cesta je pli dlouh"
#define MSG_CANT_PASV "Nemete pouvat PASV na IPv4 penosech. Pouijte EPSV."
#define MSG_CANT_PASSIVE "Nemohu vytvoit pasivn spojen"
#define MSG_PORTS_BUSY "Vechny rezervovan TCP porty jsou pouvny"
#define MSG_GETSOCKNAME_DATA "Nemohu identifikovat lokaln datov socket"
#define MSG_GETPEERNAME "Nemohu identifikovat lokaln socket"
#define MSG_INVALID_IP "Lituji, ale zadali jste chybnou adresu"
#define MSG_NO_EPSV "Prosm pouijte klienta kompatiblinho s IPv6 s podporou EPSV"
#define MSG_BAD_PORT "Lituji, ale nepipojm se na port ni ne 1024"
#define MSG_NO_FXP "Neotevu spojen na %s (pouze do %s)"
#define MSG_FXP "FXP penos : z %s na %s"
#define MSG_NO_DATA_CONN "dn datov spojen"
#define MSG_ACCEPT_FAILED "Spojen nemohlo bt akceptovno"
#define MSG_ACCEPT_SUCCESS "Datov spojen pijat"
#define MSG_CNX_PORT_FAILED "Nemohu vytvoit datov spojen na port %d"
#define MSG_CNX_PORT "Pipjm se na port %d"
#define MSG_ANON_CANT_MKD "Lituji, ale anonymn uivatel neme vytvet adrese"
#define MSG_ANON_CANT_RMD "Lituji, ale anonymn uivatel neme mazat adrese"
#define MSG_ANON_CANT_RENAME "Anonymn uivatel neme pesuvat/pejmenovvat soubory"
#define MSG_ANON_CANT_CHANGE_PERMS "Anonymn uivatel neme mnit pstupov prva"
#define MSG_GLOB_NO_MEMORY "Bhem globbingu %s dola pam"
#define MSG_PROBABLY_DENIED "(Tohle pravdpodobn znamen \"Odmtnut pstup\")"
#define MSG_GLOB_READ_ERROR "Chyba ten pi globbovan %s"
#define MSG_GLOB_NO_MATCH "dn shoda mezi %s v %s"
#define MSG_CHMOD_FAILED "Nemohu zmnit pstupov prva na %s"
#define MSG_CHMOD_SUCCESS "Pstupov prva zmnna na %s"
#define MSG_CHMOD_TOTAL_FAILURE "Lituji, ale nemohl jsem zmnit dn pstupov prva"
#define MSG_ANON_CANT_DELETE "Anonymn uivatel neme mazat soubory"
#define MSG_ANON_CANT_OVERWRITE "Anonymn uivatel neme pepisovat existujc soubory"
#define MSG_DELE_FAILED "%s nelze smazat"
#define MSG_DELE_SUCCESS "Soubor %s smazn"
#define MSG_DELE_TOTAL_FAILURE "dn soubor nebyl smazn"
#define MSG_LOAD_TOO_HIGH \
  "Zt systmu, kdy jste se pihlsil, byla %3.2f. Nedovolujeme dowloady\n" \
  "anonymnm uivatelm pi tak vysok zti. Uploady jsou vdy povoleny\n"

#define MSG_OPEN_FAILURE "Nemohu otevt %s"
#define MSG_OPEN_FAILURE2 "Nemohu otevt ten soubor"
#define MSG_STAT_FAILURE "Nemohu zjistit velikost souboru"
#define MSG_STAT_FAILURE2 "Nemohu ovit existenci souboru"
#define MSG_REST_TOO_LARGE_FOR_FILE "Offset %lld pro restart stahovn je pli vysok, soubor m velikost pouze %lld."
#define MSG_REST_RESET "Zatek restartu nastaven na 0"
#define MSG_NOT_REGULAR_FILE "Soubor nen bn"
#define MSG_NOT_MODERATED \
     "Tento soubor byl uploadnut anonymnm uivatelem. Administrtor serveru " \
     "ho pro download zatm neschvlil."
#define MSG_RATIO_DENIAL \
     "Lituji, ale pomr upload/download je %u:%u .\n" \
     "Zatm jste uploadli %llu kilobajt, downloadli %llu kilobajt.\n" \
     "Jestli nm tu uploadnete nco hezkho, mete si pak na opltku taky nco hezkho sthnout."
#define MSG_NO_MORE_TO_DOWNLOAD "Na download tu u nic nen"
#define MSG_WINNER "Pota je tvj ptel. Dvuj mu!"
#define MSG_KBYTES_LEFT "%.1f kilobajt na download"
#define MSG_ABORTED "Penos peruen"
#define MSG_DATA_WRITE_FAILED "Chyba bhem zpisu do datovho spojen"
#define MSG_DATA_READ_FAILED "Chyba bhem ten z datovho spojen"
#define MSG_MMAP_FAILED "Nemu namapovat soubor do pamti"
#define MSG_WRITE_FAILED "Chyba bhem zpisu do souboru"
#define MSG_TRANSFER_RATE_M "%.3f sekund (meno zde), %.2f megabajt za sekundu"
#define MSG_TRANSFER_RATE_K "%.3f sekund (meno zde), %.2f kilobajt za sekundu"
#define MSG_TRANSFER_RATE_B "%.3f sekund (meno zde), %.2f bajt za sekundu"
#define MSG_SPACE_FREE_M "%.1f megabajt volnho diskovho prostoru"
#define MSG_SPACE_FREE_K "%f kilobjat volnho diskovho prostoru"
#define MSG_DOWNLOADED "downloadnut"
#define MSG_REST_NOT_NUMERIC "REST vyaduje seln parametr"
#define MSG_REST_ASCII_STRICT "Oznaen odpovdi mus bt 0 v ASCII reimu"
#define MSG_REST_ASCII_WORKAROUND "Pokrauji od %lld. Ale jsme v ASCII reimu"
#define MSG_REST_SUCCESS "Pokrauji od %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Zakzan nzev adrese"
#define MSG_SANITY_FILE_FAILURE "Zakzan nzev souboru: %s"
#define MSG_MKD_FAILURE "Nemohu vytvoit adres"
#define MSG_MKD_SUCCESS "Adres byl spn vytvoen"
#define MSG_RMD_FAILURE "Nemohu smazat adres"
#define MSG_RMD_SUCCESS "Adres byl spn smazn"
#define MSG_TIMESTAMP_FAILURE "Nemohu zskat asovu znaku"
#define MSG_MODE_ERROR "Podporovn je pouze ASCII a binrn reim"
#define MSG_CREATE_FAILURE "Nemohu vytvoit soubor"
#define MSG_ABRT_ONLY "Pkaz ABRT je mon pout pouze bhem uploadu."
#define MSG_UPLOAD_PARTIAL "stn uploadnut"
#define MSG_REMOVED "odstrann"
#define MSG_UPLOADED "uploadnut"
#define MSG_GMTIME_FAILURE "Nemohu zjistit lokln as"
#define MSG_TYPE_8BIT_FAILURE "Podporuju pouze 8 bitov bajty, odkud jste piel, love??"
#define MSG_TYPE_UNKNOWN "Neznm TYPE"
#define MSG_TYPE_SUCCESS "TYPE je nyn"
#define MSG_STRU_FAILURE "Pouze F(ile) je podporovn"
#define MSG_MODE_FAILURE "Prosm pouijte S(tream) reim"
#define MSG_RENAME_ABORT "Peruuji pedel pejmenovn"
#define MSG_RENAME_RNFR_SUCCESS "Pkaz RNFR byl akceptovn, soubor existuje, oekvm cl"
#define MSG_FILE_DOESNT_EXIST "Lituji, ale zadan soubor neexistuje"
#define MSG_RENAME_ALREADY_THERE "Pkaz RENAME selhal - clov soubor ji existuje"
#define MSG_RENAME_NORNFR "Potebuji RNFR ped RNTO"
#define MSG_RENAME_FAILURE "Chyba pemenovn/pesunu"
#define MSG_RENAME_SUCCESS "Soubor spnn pesunut/pemenovn"
#define MSG_NO_SUPERSERVER "Prosm spoutjte pure-ftpd ze super-serveru (napklad z tcpserver)"
#define MSG_NO_FTP_ACCOUNT "Nemohu najt et 'ftp'"
#define MSG_CONF_ERR "Chyba konfigurace"
#define MSG_NO_VIRTUAL_FILE "Chybjc soubor virtualnch uivatel"
#define MSG_ILLEGAL_THROTTLING "Chybn hodnota krcen rychlosti penosu"
#define MSG_ILLEGAL_TRUSTED_GID "Chybn dvovan gid pro chroot"
#define MSG_ILLEGAL_USER_LIMIT "Chybn limit uivatel"
#define MSG_ILLEGAL_FACILITY "Neznm jmno sluby"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Chybn konfiguran soubor LDAPu"
#define MSG_ILLEGAL_LOAD_LIMIT "Chyn limit meze zte systmu"
#define MSG_ILLEGAL_PORTS_RANGE "Chybn rozsah port"
#define MSG_ILLEGAL_LS_LIMITS "Chybn limit pro 'ls'"
#define MSG_ILLEGAL_FORCE_PASSIVE "Chybn vnucen IP pro pasivn penosy"
#define MSG_ILLEGAL_RATIO "Chybn upload/download pomr"
#define MSG_ILLEGAL_UID_LIMIT "Chybn uid limit"
#define MSG_ILLEGAL_OPTION "Neznm run-time volba"
#define MSG_LDAP_MISSING_BASE "Chybjc LDAPBaseDN v konfiguranm souboru LDAPu"
#define MSG_LDAP_WRONG_PARMS "Chybn LDAP parametry"
#define MSG_NEW_CONNECTION "Nov spojen z %s"
#define MSG_WELCOME_TO "Vtejte na"
#define MSG_MAX_USERS "Lituji, ale %lu (maximum) uivatel je ji pihlench"
#define MSG_NB_USERS "Jste uivatelem slo %d z %d povolench"
#define MSG_WELCOME_TIME "Lokaln as je %02d:%02d. Port serveru je %u."
#define MSG_ANONYMOUS_FTP_ONLY "Zde je povolen pouze anonymn pstup"
#define MSG_RATIOS_EVERYONE "VICHNI UIVATELE MUSI DODRET POMER UL/DL :"
#define MSG_RATIOS_ANONYMOUS "ANONYMNI UIVATELE MUSI DODRET POMER UL/DL :"
#define MSG_RATIOS_RULE "na download %u MB muste uploadnut %u MB."
#define MSG_INFO_IDLE_M "Budete odpojeni po %lu minutch neinnosti."
#define MSG_INFO_IDLE_S "Budete odpojeni po %lu sekundch neinnosti."
#define MSG_CANT_READ_FILE "Lituji, nebyl jsem schopn pest [%s]"
#define MSG_LS_TRUNCATED "Vstup zkrcen na %u shod"
#define MSG_LS_SUCCESS "Spolu %u shod"
#define MSG_LOGOUT "Logout."
#define MSG_AUTH_FAILED_LOG "Autentifikace uivatele selhala [%s]"
#define MSG_ILLEGAL_UMASK "Neplatn maska"
#define MSG_STANDALONE_FAILED "Nemohu spustit samostatn server"
#define MSG_NO_ANONYMOUS_LOGIN "Tohle je soukrom systm - anonymn uivatel jsou zakzni"
#define MSG_ANONYMOUS_ANY_PASSWORD "Mete zadat libovoln heslo"
#define MSG_MAX_USERS_IP "Pli mnoho aktivnch spojen (%lu) z va IP"
#define MSG_ACTIVE_DISABLED "Aktivn reim je vypnut"
#define MSG_TRANSFER_SUCCESSFUL "Soubor byl spn penesen"
#define MSG_NO_DISK_SPACE "Disk je pln, zkuste pozdji"
#define MSG_OUT_OF_MEMORY "Nedostatek pamti"
#define MSG_ILLEGAL_TRUSTED_IP "Neplatn dvovan IP adresa"
#define MSG_NO_ASCII_RESUME "Pokraovn penosu v ASCII reime nen bezpen, soubor nejdv smate, prosm"
#define MSG_UNKNOWN_ALTLOG "Neznm logovac formt"
#define MSG_ACCOUNT_DISABLED "Nemete se pihlsit jako [%s] : et je deaktivovn"
#define MSG_SQL_WRONG_PARMS "Chybn SQL parametry"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Chybn konfiguran soubor SQL"
#define MSG_SQL_MISSING_SERVER "V konfiguranm souboru chyb SQL server"
#define MSG_SQL_DOWN "Vypad to, e SQL server spadl"
#define MSG_ILLEGAL_QUOTA "Chybn kvota"
#define MSG_QUOTA_FILES "%llu soubor pouitch (%d%%) - autorizovanch: %llu soubor"
#define MSG_QUOTA_SIZE "%llu kilobajt pouitch (%d%%) - autorizovanch: %llu kilobajt"
#define MSG_QUOTA_EXCEEDED "Kvota pekroena: [%s] nebude uloen"
#define MSG_AUTH_UNKNOWN "Neznm autentifikan metoda"
#define MSG_PDB_BROKEN "Nebylo mon pest indexovan soubor puredb (nebo byla detekovna star verze) - Vyzkouejte spustit pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s je alias pro %s."
#define MSG_ALIASES_UNKNOWN "Neznm alias %s."
#define MSG_ALIASES_BROKEN_FILE "Pokozen soubor s aliasy"
#define MSG_ALIASES_LIST "Jsou dostupn nasledujc aliasy:"
#define MSG_PERUSER_MAX "Nemohu akceptovat vc ne %lu pipojen stejnho uivatele"
#define MSG_IPV6_OK "Na tento server se lze rovn pipojovat pouitm IPv6 protokolu"
#define MSG_TLS_INFO "SSL/TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "SSL/TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using SSL/TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "SSL/TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
